@@ -45,7 +45,7 @@
 #include "camel-mapi-store-summary.h"
 #include "camel-mapi-utils.h"
 
-#define d(x) x
+#define d(x)
 
 #define STREAM_SIZE 4000
 
@@ -121,7 +121,7 @@ mail_item_set_subject(MailItem *item, const gchar *subject)
 #define MAX_READ_SIZE 0x1000
 
 static void
-mail_item_set_body_stream (MailItem *item, CamelStream *body, MailItemPartType part_type)
+mail_item_set_body_stream (MailItem *item, CamelStream *body, MailItemPartType part_type, GCancellable *cancellable)
 {
 	guint8 *buf = g_new0 (guint8 , STREAM_SIZE);
 	guint32	read_size = 0, i;
@@ -132,7 +132,7 @@ mail_item_set_body_stream (MailItem *item, CamelStream *body, MailItemPartType p
 
 	stream->value = g_byte_array_new ();
 
-	while (read_size = camel_stream_read (body, (gchar *)buf, STREAM_SIZE, NULL), read_size > 0) {
+	while (read_size = camel_stream_read (body, (gchar *)buf, STREAM_SIZE, cancellable, NULL), read_size > 0) {
 		stream->value = g_byte_array_append (stream->value, buf, read_size);
 
 		is_null_terminated = buf [read_size - 1] == 0;
@@ -175,11 +175,7 @@ mail_item_set_body_stream (MailItem *item, CamelStream *body, MailItemPartType p
 		in_unicode = g_convert ((const gchar *)stream->value->data, stream->value->len, "UTF-16", "UTF-8", NULL, &written, NULL);
 		if (in_unicode && written > 0) {
 			g_byte_array_set_size (stream->value, 0);
-			/* skip Unicode marker, if there */
-			if (written >= 2 && (const guchar) in_unicode[0] == 0xFF && (const guchar) in_unicode[1] == 0xFE)
-				g_byte_array_append (stream->value, (const guint8 *) in_unicode + 2, written - 2);
-			else
-				g_byte_array_append (stream->value, (const guint8 *) in_unicode, written);
+			g_byte_array_append (stream->value, (const guint8 *) in_unicode, written);
 
 			/* null-terminated unicode string */
 			g_byte_array_append (stream->value, (const guint8 *)"", 1);
@@ -193,7 +189,7 @@ mail_item_set_body_stream (MailItem *item, CamelStream *body, MailItemPartType p
 }
 
 static gboolean
-mail_item_add_attach (MailItem *item, CamelMimePart *part, CamelStream *content_stream)
+mail_item_add_attach (MailItem *item, CamelMimePart *part, CamelStream *content_stream, GCancellable *cancellable)
 {
 	guint8 *buf = g_new0 (guint8 , STREAM_SIZE);
 	const gchar *content_id = NULL;
@@ -255,7 +251,7 @@ mail_item_add_attach (MailItem *item, CamelMimePart *part, CamelStream *content_
 	stream->value = g_byte_array_new ();
 
 	camel_seekable_stream_seek((CamelSeekableStream *)content_stream, 0, CAMEL_STREAM_SET, NULL);
-	while (read_size = camel_stream_read(content_stream, (gchar *)buf, STREAM_SIZE, NULL), read_size > 0) {
+	while (read_size = camel_stream_read(content_stream, (gchar *)buf, STREAM_SIZE, cancellable, NULL), read_size > 0) {
 		stream->value = g_byte_array_append (stream->value, buf, read_size);
 	}
 
@@ -266,7 +262,7 @@ mail_item_add_attach (MailItem *item, CamelMimePart *part, CamelStream *content_
 }
 
 static gboolean
-mapi_do_multipart (CamelMultipart *mp, MailItem *item, gboolean *is_first)
+mapi_do_multipart (CamelMultipart *mp, MailItem *item, gboolean *is_first, GCancellable *cancellable)
 {
 	CamelDataWrapper *dw;
 	CamelStream *content_stream;
@@ -287,7 +283,7 @@ mapi_do_multipart (CamelMultipart *mp, MailItem *item, gboolean *is_first)
 		dw = camel_medium_get_content (CAMEL_MEDIUM (part));
 		if (CAMEL_IS_MULTIPART(dw)) {
 			/* recursive */
-			if (!mapi_do_multipart (CAMEL_MULTIPART (dw), item, is_first))
+			if (!mapi_do_multipart (CAMEL_MULTIPART (dw), item, is_first, cancellable))
 				return FALSE;
 			continue;
 		}
@@ -295,7 +291,8 @@ mapi_do_multipart (CamelMultipart *mp, MailItem *item, gboolean *is_first)
 		filename = camel_mime_part_get_filename(part);
 
 		content_stream = camel_stream_mem_new();
-		content_size = camel_data_wrapper_decode_to_stream (dw, (CamelStream *) content_stream, NULL);
+		content_size = camel_data_wrapper_decode_to_stream_sync (
+			dw, (CamelStream *) content_stream, cancellable, NULL);
 
 		camel_seekable_stream_seek((CamelSeekableStream *)content_stream, 0, CAMEL_STREAM_SET, NULL);
 
@@ -305,12 +302,12 @@ mapi_do_multipart (CamelMultipart *mp, MailItem *item, gboolean *is_first)
 		type = camel_mime_part_get_content_type(part);
 
 		if (i_part == 0 && (*is_first) && camel_content_type_is (type, "text", "plain")) {
-			mail_item_set_body_stream (item, content_stream, PART_TYPE_PLAIN_TEXT);
+			mail_item_set_body_stream (item, content_stream, PART_TYPE_PLAIN_TEXT, cancellable);
 			*is_first = FALSE;
 		} else if (camel_content_type_is (type, "text", "html")) {
-			mail_item_set_body_stream (item, content_stream, PART_TYPE_TEXT_HTML);
+			mail_item_set_body_stream (item, content_stream, PART_TYPE_TEXT_HTML, cancellable);
 		} else {
-			mail_item_add_attach (item, part, content_stream);
+			mail_item_add_attach (item, part, content_stream, cancellable);
 		}
 	}
 
@@ -331,7 +328,7 @@ mail_item_set_time (time_t *item_time, time_t camel_time, gint camel_offset)
 }
 
 MailItem *
-camel_mapi_utils_mime_to_item (CamelMimeMessage *message, gint32 message_camel_flags, CamelAddress *from, GError **error)
+camel_mapi_utils_mime_to_item (CamelMimeMessage *message, gint32 message_camel_flags, CamelAddress *from, GCancellable *cancellable, GError **error)
 {
 	CamelDataWrapper *dw = NULL;
 	CamelContentType *type;
@@ -424,7 +421,7 @@ camel_mapi_utils_mime_to_item (CamelMimeMessage *message, gint32 message_camel_f
 
 	if (CAMEL_IS_MULTIPART(multipart)) {
 		gboolean is_first = TRUE;
-		if (!mapi_do_multipart (CAMEL_MULTIPART(multipart), item, &is_first))
+		if (!mapi_do_multipart (CAMEL_MULTIPART(multipart), item, &is_first, cancellable))
 			printf("camel message multi part error\n");
 	} else {
 		dw = camel_medium_get_content (CAMEL_MEDIUM (message));
@@ -433,9 +430,10 @@ camel_mapi_utils_mime_to_item (CamelMimeMessage *message, gint32 message_camel_f
 			content_type = camel_content_type_simple (type);
 
 			content_stream = (CamelStream *)camel_stream_mem_new();
-			content_size = camel_data_wrapper_decode_to_stream(dw, (CamelStream *)content_stream, NULL);
+			content_size = camel_data_wrapper_decode_to_stream_sync (
+				dw, (CamelStream *)content_stream, cancellable, NULL);
 
-			mail_item_set_body_stream (item, content_stream, PART_TYPE_PLAIN_TEXT);
+			mail_item_set_body_stream (item, content_stream, PART_TYPE_PLAIN_TEXT, cancellable);
 		}
 	}
 
