@@ -368,9 +368,14 @@ exchange_mapi_cal_util_fetch_recipients (ECalComponent *comp, GSList **recip_lis
 		const gchar *str = NULL;
 		icalparameter *param;
 
+		str = icalproperty_get_attendee (att_prop);
+		if (!str || g_ascii_strcasecmp (str, org) == 0) {
+			att_prop = icalcomponent_get_next_property (icalcomp, ICAL_ATTENDEE_PROPERTY);
+			continue;
+		}
+
 		recipient = g_new0 (ExchangeMAPIRecipient, 1);
 
-		str = icalproperty_get_attendee (att_prop);
 		if (!g_ascii_strncasecmp (str, "mailto:", 7))
 			recipient->email_id = (str) + 7;
 		else
@@ -988,12 +993,12 @@ fetch_camel_cal_comp_cb (FetchItemsCallbackData *item_data, gpointer data)
 	ECalComponent *comp = NULL;
 	mapi_id_t mid = 0;
 	icalcomponent *icalcomp = NULL;
-	gchar *str = NULL, *smid = NULL, *fileuri;
+	gchar *str = NULL, *smid = NULL, *filepath;
 
 	g_return_val_if_fail (item_data != NULL, FALSE);
 	g_return_val_if_fail (fccd != NULL, FALSE);
 
-	fileuri = g_filename_to_uri (g_get_tmp_dir (), NULL, NULL);
+	filepath = g_strdup (g_get_tmp_dir ());
 
 	if (!comp) {
 		/* read component from a mail, if not found in the calendar */
@@ -1005,13 +1010,12 @@ fetch_camel_cal_comp_cb (FetchItemsCallbackData *item_data, gpointer data)
 			smid = e_cal_component_gen_uid();
 		comp = exchange_mapi_cal_util_mapi_props_to_comp (item_data->conn, fccd->kind, smid,
 							item_data->properties, item_data->streams, item_data->recipients,
-							NULL, NULL, NULL);
-		set_attachments_to_cal_component (comp, item_data->attachments, fileuri);
+							item_data->attachments, filepath, NULL);
 		e_cal_component_set_uid (comp, smid);
 		g_free (smid);
 	}
 
-	g_free (fileuri);
+	g_free (filepath);
 
 	icalcomp = e_cal_util_new_top_level ();
 	icalcomponent_set_method (icalcomp, fccd->method);
@@ -1239,7 +1243,7 @@ exchange_mapi_cal_utils_write_props_cb (ExchangeMapiConnection *conn, mapi_id_t
 	struct icaltimetype dtstart, dtend, utc_dtstart, utc_dtend;
 	const icaltimezone *utc_zone;
 	const gchar *dtstart_tz_location, *dtend_tz_location, *text = NULL;
-	struct timeval t;
+	time_t tt;
 
 	g_return_val_if_fail (conn != NULL, FALSE);
 	g_return_val_if_fail (mem_ctx != NULL, FALSE);
@@ -1275,12 +1279,8 @@ exchange_mapi_cal_utils_write_props_cb (ExchangeMapiConnection *conn, mapi_id_t
 
 	#define set_datetime_value(hex, dtval) G_STMT_START {		\
 		struct FILETIME	filetime;				\
-		NTTIME		nttime;					\
 									\
-		nttime = timeval_to_nttime(dtval);				\
-									\
-		filetime.dwLowDateTime = (nttime << 32) >> 32;		\
-		filetime.dwHighDateTime = nttime >> 32;			\
+		exchange_mapi_util_time_t_to_filetime (dtval, &filetime); \
 									\
 		if (!exchange_mapi_utils_add_spropvalue (mem_ctx, values, n_values, hex, &filetime)) \
 			return FALSE;	\
@@ -1288,12 +1288,8 @@ exchange_mapi_cal_utils_write_props_cb (ExchangeMapiConnection *conn, mapi_id_t
 
 	#define set_named_datetime_value(named_id, dtval) G_STMT_START { \
 		struct FILETIME	filetime;				\
-		NTTIME		nttime;					\
 									\
-		nttime = timeval_to_nttime(dtval);				\
-									\
-		filetime.dwLowDateTime = (nttime << 32) >> 32;		\
-		filetime.dwHighDateTime = nttime >> 32;			\
+		exchange_mapi_util_time_t_to_filetime (dtval, &filetime); \
 									\
 		if (!exchange_mapi_utils_add_spropvalue_named_id (conn, fid, mem_ctx, values, n_values, named_id, &filetime)) \
 			return FALSE;	\
@@ -1393,13 +1389,11 @@ exchange_mapi_cal_utils_write_props_cb (ExchangeMapiConnection *conn, mapi_id_t
 		}
 	set_named_value (PidLidReminderSet, &b);
 	set_named_value (PidLidReminderDelta, &flag32);
-	t.tv_sec = icaltime_as_timet (utc_dtstart);
-	t.tv_usec = 0;
-	set_named_datetime_value (PidLidReminderTime, &t);
-	t.tv_sec = icaltime_as_timet (utc_dtstart) - (flag32 * SECS_IN_MINUTE);
-	t.tv_usec = 0;
+	tt = icaltime_as_timet (utc_dtstart);
+	set_named_datetime_value (PidLidReminderTime, tt);
+	tt = icaltime_as_timet (utc_dtstart) - (flag32 * SECS_IN_MINUTE);
 	/* ReminderNextTime: FIXME for recurrence */
-	set_named_datetime_value (PidLidReminderSignalTime, &t);
+	set_named_datetime_value (PidLidReminderSignalTime, tt);
 
 	/* Sensitivity, Private */
 	flag32 = olNormal;	/* default */
@@ -1412,15 +1406,13 @@ exchange_mapi_cal_utils_write_props_cb (ExchangeMapiConnection *conn, mapi_id_t
 	set_value (PR_SENSITIVITY, &flag32);
 	set_named_value (PidLidPrivate, &b);
 
-	t.tv_sec = icaltime_as_timet (utc_dtstart);
-	t.tv_usec = 0;
-	set_named_datetime_value (PidLidCommonStart, &t);
-	set_datetime_value (PR_START_DATE, &t);
+	tt = icaltime_as_timet (utc_dtstart);
+	set_named_datetime_value (PidLidCommonStart, tt);
+	set_datetime_value (PR_START_DATE, tt);
 
-	t.tv_sec = icaltime_as_timet (utc_dtend);
-	t.tv_usec = 0;
-	set_named_datetime_value (PidLidCommonEnd, &t);
-	set_datetime_value (PR_END_DATE, &t);
+	tt = icaltime_as_timet (utc_dtend);
+	set_named_datetime_value (PidLidCommonEnd, tt);
+	set_datetime_value (PR_END_DATE, tt);
 
 	b = 1;
 	set_value (PR_RESPONSE_REQUESTED, &b);
@@ -1467,11 +1459,10 @@ exchange_mapi_cal_utils_write_props_cb (ExchangeMapiConnection *conn, mapi_id_t
 		set_named_value (PidLidAutoFillLocation, &b);
 
 		/* Start */
-		t.tv_sec = icaltime_as_timet (utc_dtstart);
-		t.tv_usec = 0;
-		set_named_datetime_value (PidLidAppointmentStartWhole, &t);
+		tt = icaltime_as_timet (utc_dtstart);
+		set_named_datetime_value (PidLidAppointmentStartWhole, tt);
 		/* FIXME: for recurrence */
-		set_named_datetime_value (PidLidClipStart, &t);
+		set_named_datetime_value (PidLidClipStart, tt);
 
 		/* Start TZ */
 		mapi_tzid = exchange_mapi_cal_tz_util_get_mapi_equivalent ((dtstart_tz_location && *dtstart_tz_location) ? dtstart_tz_location : "UTC");
@@ -1481,11 +1472,10 @@ exchange_mapi_cal_utils_write_props_cb (ExchangeMapiConnection *conn, mapi_id_t
 		}
 
 		/* End */
-		t.tv_sec = icaltime_as_timet (utc_dtend);
-		t.tv_usec = 0;
-		set_named_datetime_value (PidLidAppointmentEndWhole, &t);
+		tt = icaltime_as_timet (utc_dtend);
+		set_named_datetime_value (PidLidAppointmentEndWhole, tt);
 		/* FIXME: for recurrence */
-		set_named_datetime_value (PidLidClipEnd, &t);
+		set_named_datetime_value (PidLidClipEnd, tt);
 
 		/* End TZ */
 		mapi_tzid = exchange_mapi_cal_tz_util_get_mapi_equivalent ((dtend_tz_location && *dtend_tz_location) ? dtend_tz_location : "UTC");
@@ -1726,25 +1716,22 @@ exchange_mapi_cal_utils_write_props_cb (ExchangeMapiConnection *conn, mapi_id_t
 			completed = icalproperty_get_completed (prop);
 
 			completed.hour = completed.minute = completed.second = 0; completed.is_date = completed.is_utc = 1;
-			t.tv_sec = icaltime_as_timet (completed);
-			t.tv_usec = 0;
-			set_named_datetime_value (PidLidTaskDateCompleted, &t);
+			tt = icaltime_as_timet (completed);
+			set_named_datetime_value (PidLidTaskDateCompleted, tt);
 		}
 
 		/* Start */
 		dtstart.hour = dtstart.minute = dtstart.second = 0; dtstart.is_date = dtstart.is_utc = 1;
-		t.tv_sec = icaltime_as_timet (dtstart);
-		t.tv_usec = 0;
+		tt = icaltime_as_timet (dtstart);
 		if (!icaltime_is_null_time (dtstart)) {
-			set_named_datetime_value (PidLidTaskStartDate, &t);
+			set_named_datetime_value (PidLidTaskStartDate, tt);
 		}
 
 		/* Due */
 		dtend.hour = dtend.minute = dtend.second = 0; dtend.is_date = dtend.is_utc = 1;
-		t.tv_sec = icaltime_as_timet (dtend);
-		t.tv_usec = 0;
+		tt = icaltime_as_timet (dtend);
 		if (!icaltime_is_null_time (dtend)) {
-			set_named_datetime_value (PidLidTaskDueDate, &t);
+			set_named_datetime_value (PidLidTaskDueDate, tt);
 		}
 
 		/* FIXME: Evolution does not support recurring tasks */
